//-----------------------------------------------------------------------------
// File: platform_win.cpp
//
// Copyright (c) Astralax. All rights reserved.
// Author: Sedov Alexey
//-----------------------------------------------------------------------------

#include "s3eTimer.h"
#include "platform_marmalade.h"

MP_Platform_MARMALADE::MP_Platform_MARMALADE()
{
}
//------------------------------------------------------------
MP_Platform_MARMALADE::~MP_Platform_MARMALADE()
{
}
//------------------------------------------------------------
// eng: Returns time in milliseconds
// rus: Возвращает время в милисекундах
unsigned long MP_Platform_MARMALADE::GetTick()
{
	return (unsigned long)s3eTimerGetMs();
}
//------------------------------------------------------------
// eng: Returns path to folder with emitters
// rus: Возвращает путь к папке с ptc-файлами
const char* MP_Platform_MARMALADE::GetPathToPTC()
{
	if (ptc_path.empty())
	{
		#ifdef MAGIC_3D
		ptc_path="particles3d/";
		#else
		ptc_path="particles2d/";
		#endif
	}

	return ptc_path.c_str();
}
//------------------------------------------------------------
// eng: Returns path to folder with textures
// rus: Возвращает путь к папке с текстурами
const char* MP_Platform_MARMALADE::GetPathToTexture()
{
	if (texture_path.empty())
	{
		texture_path=GetPathToPTC();
		texture_path+="textures/";
	}

	return texture_path.c_str();
}
//------------------------------------------------------------
// eng: Returns path to folder which could be used by wrapper to store temporary files
// rus: Возвращает путь к временной папке
const char* MP_Platform_MARMALADE::GetPathToTemp()
{
	return NULL;	// папка отсутствует, поэтому временные файлы будут сохраняться в ОЗУ
}
//------------------------------------------------------------
// eng: Finds the first ptc-file in emitters folder
// rus: Поиск первого ptc-файла в папке с эмиттерами
const char* MP_Platform_MARMALADE::GetFirstFile()
{
	std::string dir_particles=GetPathToPTC();

	file_list=s3eFileListDirectory(dir_particles.c_str());

	char pBuf[250];
	while((s3eFileListNext(file_list, pBuf, sizeof(pBuf))!=S3E_RESULT_ERROR))
	{
		found_file=pBuf;
		if (found_file.find(".ptc")!=std::string::npos)
			return found_file.c_str();
	}

	s3eFileListClose(file_list);
	return NULL;
}
//------------------------------------------------------------
const char* MP_Platform_MARMALADE::GetNextFile()
{
	char pBuf[250];
	while((s3eFileListNext(file_list, pBuf, sizeof(pBuf))!=S3E_RESULT_ERROR))
	{
		found_file=pBuf;
		if (found_file.find(".ptc")!=std::string::npos)
			return found_file.c_str();
	}
	s3eFileListClose(file_list);
	return NULL;
}
//------------------------------------------------------------


int MP_Platform_MARMALADE::RemoveFile(const char* file)
{
	if (s3eFileDelete(file)==S3E_RESULT_SUCCESS)
		return 0;
	return 1;
}